@@ -2,17 +2,20 @@
 
 from django import forms
 from django.contrib.gis.geos import Point
+from django.contrib.auth import get_user_model
 from django.utils.translation import ugettext_lazy as _
 from django.template.defaultfilters import slugify
 from django.conf import settings
 from django.forms.util import ErrorList
 
-from .models import Map, DataLayer, User
+from .models import Map, DataLayer
 
 DEFAULT_LATITUDE = settings.LEAFLET_LATITUDE if hasattr(settings, "LEAFLET_LATITUDE") else 51
 DEFAULT_LONGITUDE = settings.LEAFLET_LONGITUDE if hasattr(settings, "LEAFLET_LONGITUDE") else 2
 DEFAULT_CENTER = Point(DEFAULT_LONGITUDE, DEFAULT_LATITUDE)
 
+User = get_user_model()
+
 
 class FlatErrorList(ErrorList):
     def __unicode__(self):
